@@ -1,4 +1,4 @@
-/* $Id: re2dfa.c 319 2010-03-19 22:19:39Z nick $
+/* $Id: re2dfa.c 330 2012-07-13 23:11:14Z nick $
 // Copyright (c) 2001,2002                        RIPE NCC
 //
 // All Rights Reserved
@@ -1733,7 +1733,7 @@ rd_state *rd_intersect_map_find(register rd_state *stt1,
    for (triple = rd_intersect_map.dll.rq_forw->rq_self; 
 	triple != &rd_intersect_map
 	   && (triple->first < stt1 
-	       || triple->first == stt1 && triple->second < stt2); 
+	       || (triple->first == stt1 && triple->second < stt2)); 
 	triple = triple->dll.rq_forw->rq_self)
 	   ;
 
