@@ -1,4 +1,4 @@
-//  $Id: prefix.cc 319 2010-03-19 22:19:39Z nick $
+//  $Id: prefix.cc 332 2012-07-17 10:35:17Z nick $
 // Copyright (c) 2001,2002                        RIPE NCC
 //
 // All Rights Reserved
@@ -55,6 +55,8 @@
 #include <sys/types.h>
 #include <algorithm>
 #include <iterator>
+#include <arpa/inet.h>
+#include <sys/socket.h>
 
 using namespace std;
 
@@ -174,16 +176,15 @@ void PrefixRange::parse(const char *name)
   unsigned int i1, i2, i3, i4, uiLength = 0, uiN = 0, uiM = 0;
   char ch = ' ';
 
-  const char *p;
   if (strstr(name, "^+"))
     // Inclusive more specific operation
     sscanf(name, "%u.%u.%u.%u/%u^%c", &i1, &i2, &i3, &i4, &uiLength, &ch);
-  else if (p = strstr(name, "^-"))
+  else if (strstr(name, "^-"))
      sscanf(name, "%u.%u.%u.%u/%u^%c", &i1, &i2, &i3, &i4, &uiLength, &ch);
-  else if (p = strchr(name, '-')) 
+  else if (strchr(name, '-')) 
      sscanf(name, "%u.%u.%u.%u/%u^%u-%u", 
 	    &i1, &i2, &i3, &i4, &uiLength, &uiN, &uiM);
-  else if (p = strchr(name, '^')) {
+  else if (strchr(name, '^')) {
      sscanf(name, "%u.%u.%u.%u/%u^%u", 
 	    &i1, &i2, &i3, &i4, &uiLength, &uiN);
      uiM = uiN;
@@ -413,60 +414,44 @@ IPv6PrefixRange MulticastIPv6PrefixRange("ff00::/8^8-128");
 
 /* IPv6 stuff */
 
+int check_big_endian()
+{
+   unsigned long onebit = 1;
+   return !(*((char *)(&onebit)));
+}
+                        
 // ipv6_addr_t to string - pointers should be provided
 char* ipv62hex(ipv6_addr_t *ip, char *buffer){
-   unsigned int i[8];
-   int j = 0;
+   unsigned char i[16];
+   int j;
 
    ip_v6word_t high = ip->high;
    ip_v6word_t low = ip->low;
 
-   i[0] = (high >> 48) & 0xFFFF;
-   i[1] = (high >> 32) & 0xFFFF;
-   i[2] = (high >> 16) & 0xFFFF;
-   i[3] = high & 0xFFFF;
-   i[4] = (low >> 48) & 0xFFFF;
-   i[5] = (low >> 32) & 0xFFFF;
-   i[6] = (low >> 16) & 0xFFFF;
-   i[7] = low & 0xFFFF;
+   /* irrtoolset was written before inet_ntop() and friends were written. 
+      inet_ntop() expects big-endian layout, but ip_v6word_t uses the
+      machine architecture and is not endian-clean, so on little-endian
+      machines we need to do a byte-swap.  This is done in two bits because
+      the integer value of ip_v6word_t is private.  The endian check is done
+      in runtime; compile-time checks of endianness are a broken concept due
+      to complications like cross-compilation, fat binaries with
+      mixed-architecture sections and mixed endian chips.  */
 
-   memset(buffer, 0, strlen(buffer));
- 
-
-   // do non-compressed
-
-  /* while (j <= 7) {
-     sprintf(buffer + strlen(buffer), "%X", i[j]); 
-     if (j != 7)
-       sprintf(buffer + strlen(buffer), ":");
-     j++;
-   }
-  */
-
-   while ((j <= 7) && (i[j] != 0)) {
-     sprintf(buffer + strlen(buffer), "%X", i[j]); 
-     if (j != 7)
-       sprintf(buffer + strlen(buffer), ":");
-     j++;
+   if (check_big_endian()) {
+      memcpy(i, ip, 16);
+   } else {
+      // assume little endian here.  If you're running on a pdp, you have
+      // bigger problems.
+      for (j = 0; j <= 7; j++) {
+         i[j]   =  (high >> (7-j)*8) & 0xFF;
+         i[j+8] =  (low  >> (7-j)*8) & 0xFF;
+      }
    }
 
-   if (i[j] == 0) {
-     while ((j <= 7) && (i[j] == 0)) {
-       if (j == 0)
-         sprintf(buffer + strlen(buffer), ":");
-       j++;
-     }
-     sprintf(buffer + strlen(buffer), ":");
-   }
-
-   while (j <= 7) {
-     sprintf(buffer + strlen(buffer), "%X", i[j]);
-     if (j != 7)
-      sprintf(buffer + strlen(buffer), ":");
-     j++;
-   } 
-   return(buffer);
+   memset(buffer, 0, IPV6_LENGTH);
+   inet_ntop (AF_INET6, &i, buffer, IPV6_LENGTH);
 
+   return (buffer);
 }
 
 // string to ipv6_addr_t - pointers should be provided
@@ -587,7 +572,7 @@ void IPv6PrefixRange::parse(const char *name)
   ipaddr = (ipv6_addr_t *) calloc (sizeof(ipv6_addr_t),1);
   ipv6_addr_t t = *ipaddr;
 
-  if (slash = strstr (name, "/")) {
+  if ((slash = strstr (name, "/"))) {
     strncat (address, name, strlen (name) - strlen(slash));
     //printf ("original: %s\n", name);
     //printf ("address part: %s\n", address);
