@@ -1,4 +1,4 @@
-//  $Id: schema_rpsl.cc 319 2010-03-19 22:19:39Z nick $
+//  $Id: schema_rpsl.cc 327 2012-04-19 12:46:16Z nick $
 // Copyright (c) 2001,2002                        RIPE NCC
 //
 // All Rights Reserved
@@ -234,6 +234,8 @@ CMN_ATTRS
 "attr:  aggr-mtd         syntax(special, aggr-mtd),                             optional,  single\n"
 "attr:  export-comps     syntax(special, filter),                         optional,  single\n"
 "attr:  holes            syntax(ListOfIPv4Prefix),                              optional,  multiple\n"
+"attr:  pingable                                                                optional,  multiple\n"
+"attr:  ping-hdl         syntax(list of rpsl_word),                             optional,  multiple\n"
 CMN_ATTRS
 "attr:  descr                                                                   mandatory, multiple\n"
 "attr:  mnt-by           syntax(list of rpsl_word),                             mandatory, multiple, lookup\n"
@@ -255,6 +257,8 @@ CMN_ATTRS
 "attr:  aggr-mtd         syntax(special, aggr-mtd),                             optional,  single\n"
 "attr:  export-comps     syntax(special, v6_filter),                         optional,  single\n"
 "attr:  holes            syntax(ListOfIPv6Prefix),                              optional,  multiple\n"
+"attr:  pingable                                                                optional,  multiple\n"
+"attr:  ping-hdl         syntax(list of rpsl_word),                             optional,  multiple\n"
 CMN_ATTRS
 "attr:  descr                                                                   mandatory, multiple\n"
 "attr:  mnt-by           syntax(list of rpsl_word),                             mandatory, multiple, lookup\n"
@@ -359,6 +363,8 @@ CMN_ATTRS
 "attr:  status                                                                  mandatory, single\n"
 "attr:  mnt-lower        syntax(ListOfrpsl_word),                               optional,  multiple\n"
 CMN_ATTRS
+"attr:  geoloc                                                                  optional,  single\n"
+"attr:  language                                                                optional,  multiple\n"
 "attr:  descr                                                                   mandatory, multiple\n"
 "attr:  mnt-by           syntax(list of rpsl_word),                             optional,  multiple, lookup\n"
 "attr:  mnt-routes       syntax(special, mnt-routes),                           optional,  multiple, lookup\n"
@@ -371,8 +377,11 @@ CMN_ATTRS
 "attr:  country                                                                 mandatory, multiple\n"
 "attr:  rev-srv                                                                 optional,  multiple, lookup\n"
 "attr:  status                                                                  mandatory, single\n"
+"attr:  assignment-size                                                         optional, single\n"
 "attr:  mnt-lower        syntax(ListOfrpsl_word),                               optional,  multiple\n"
 CMN_ATTRS
+"attr:  geoloc                                                                  optional,  single\n"
+"attr:  language                                                                optional,  multiple\n"
 "attr:  descr                                                                   mandatory, multiple\n"
 "attr:  mnt-by           syntax(list of rpsl_word),                             optional,  multiple, lookup\n"
 "attr:  mnt-routes       syntax(special, mnt-routes6),                          optional,  multiple, lookup\n"
