@@ -1,4 +1,4 @@
-//  $Id: f_cisco.cc 319 2010-03-19 22:19:39Z nick $
+//  $Id: f_cisco.cc 335 2012-07-31 12:06:24Z nick $
 // Copyright (c) 2001,2002                        RIPE NCC
 //
 // All Rights Reserved
@@ -470,14 +470,16 @@ void CiscoConfig::printREASno(ostream& out, const RangeList &no) {
       out << "_";
       pi = no.ranges.head();
       put_par = ! no.ranges.isSingleton() || pi->high != pi->low || inTilda;
-      if (put_par)
-	 if (reSplittable)
+      if (put_par) {
+	 if (reSplittable) {
 	    if (inTilda)
 	       out << "&";
 	    else
 	       out << "@";
-	 else
+	 } else {
 	    out << "("; 
+         }
+      }
 
       for (; pi; pi = no.ranges.next(pi)) {
 	 for (int i = pi->low; i <= pi->high; ++i) {
@@ -1152,13 +1154,14 @@ bool CiscoConfig::printNeighbor(int import,
       cout << indent << " neighbor " << neighbor 
 	   << " route-map " << mapName << " " << direction << "\n";
    
-   if (import && ! forcedInboundMatchIP && prefixListGenerated)
+   if (import && ! forcedInboundMatchIP && prefixListGenerated) {
       if (usePrefixLists)
 	 cout << indent << " neighbor " << neighbor
 	      << " prefix-list pl" << distributeListNo << " in\n";
       else
 	 cout << indent << " neighbor " << neighbor
 	      << " distribute-list " << distributeListNo << " in\n";
+   }
 
    if (afi_activate)
       cout << " exit\n"; // exit address-family config mode
@@ -1714,12 +1717,12 @@ void CiscoConfig::importGroup(ASt asno, char * pset) {
        if (typeid(*itr()->peering->peerRtrs) == typeid(FilterRouter)  
             && typeid(*itr()->peering->peerASes) == typeid(FilterASNO))
          cout << " neighbor " << *itr()->peering->peerRtrs  
-              << " remote-as " << *itr()->peering->peerASes << endl;
+              << " remote-as " << ((FilterASNO *)itr()->peering->peerASes)->asno << endl;
      for (AttrIterator<AttrPeering> itr(prngSet, "mp-peering"); itr; itr++)
        if (typeid(*itr()->peering->peerRtrs) == typeid(FilterRouter)  
             && typeid(*itr()->peering->peerASes) == typeid(FilterASNO))
          cout << " neighbor " << *itr()->peering->peerRtrs  
-              << " remote-as " << *itr()->peering->peerASes << endl;
+              << " remote-as " << ((FilterASNO *)itr()->peering->peerASes)->asno << endl;
 
      for (Item *afi = afi_list->head(); afi; afi = afi_list->next(afi)) {
        bool afi_activate = false;
@@ -1810,12 +1813,12 @@ void CiscoConfig::exportGroup(ASt asno, char * pset) {
        if (typeid(*itr()->peering->peerRtrs) == typeid(FilterRouter)  
             && typeid(*itr()->peering->peerASes) == typeid(FilterASNO))
          cout << " neighbor " << *itr()->peering->peerRtrs  
-              << " remote-as " << *itr()->peering->peerASes << endl;
+              << " remote-as " << ((FilterASNO *)itr()->peering->peerASes)->asno << endl;
      for (AttrIterator<AttrPeering> itr(prngSet, "mp-peering"); itr; itr++)
        if (typeid(*itr()->peering->peerRtrs) == typeid(FilterRouter)  
             && typeid(*itr()->peering->peerASes) == typeid(FilterASNO))
          cout << " neighbor " << *itr()->peering->peerRtrs  
-              << " remote-as " << *itr()->peering->peerASes << endl;
+              << " remote-as " << ((FilterASNO *)itr()->peering->peerASes)->asno << endl;
 
      for (Item *afi = afi_list->head(); afi; afi = afi_list->next(afi)) {
        bool afi_activate = false;
