@@ -1,4 +1,4 @@
-//  $Id: f_junos.cc 319 2010-03-19 22:19:39Z nick $
+//  $Id: f_junos.cc 333 2012-07-18 15:43:16Z nick $
 // Copyright (c) 2001,2002                        RIPE NCC
 //
 // All Rights Reserved
@@ -1225,7 +1225,7 @@ void JunosConfig::exportGroup(ASt asno, char * pset) {
       if (typeid(*itr()->peering->peerRtrs) == typeid(FilterRouter)
 	  && typeid(*itr()->peering->peerASes) == typeid(FilterASNO)) {
 	 cout << "         neighbor " << *itr()->peering->peerRtrs << " {\n"
-	      << "            peer-as " << *itr()->peering->peerASes <<";\n"
+	      << "            peer-as " << ((FilterASNO *)itr()->peering->peerASes)->asno <<";\n"
 	      << "         }\n";
       }
    }   
@@ -1233,7 +1233,7 @@ void JunosConfig::exportGroup(ASt asno, char * pset) {
       if (typeid(*itr()->peering->peerRtrs) == typeid(FilterRouter)
 	  && typeid(*itr()->peering->peerASes) == typeid(FilterASNO)) {
 	 cout << "         neighbor " << *itr()->peering->peerRtrs << " {\n"
-	      << "            peer-as " << *itr()->peering->peerASes <<";\n"
+	      << "            peer-as " << ((FilterASNO *)itr()->peering->peerASes)->asno <<";\n"
 	      << "         }\n";
       }
    }   
@@ -1327,7 +1327,7 @@ void JunosConfig::importGroup(ASt asno, char * pset) {
       if (typeid(*itr()->peering->peerRtrs) == typeid(FilterRouter)
 	  && typeid(*itr()->peering->peerASes) == typeid(FilterASNO)) {
 	 cout << "         neighbor " << *itr()->peering->peerRtrs << " {\n"
-	      << "            peer-as " << *itr()->peering->peerASes <<";\n"
+	      << "            peer-as " << ((FilterASNO *)itr()->peering->peerASes)->asno <<";\n"
 	      << "         }\n";
       }
    }   
@@ -1335,7 +1335,7 @@ void JunosConfig::importGroup(ASt asno, char * pset) {
       if (typeid(*itr()->peering->peerRtrs) == typeid(FilterRouter)
 	  && typeid(*itr()->peering->peerASes) == typeid(FilterASNO)) {
 	 cout << "         neighbor " << *itr()->peering->peerRtrs << " {\n"
-	      << "            peer-as " << *itr()->peering->peerASes <<";\n"
+	      << "            peer-as " << ((FilterASNO *)itr()->peering->peerASes)->asno <<";\n"
 	      << "         }\n";
       }
    }   
